hasParams property
Whether constructor has parameters.
If false, we can treat it as a ValueGetter of T.
Implementation
late final hasParams = !_constructorText.startsWith('() => ');
Whether constructor has parameters.
If false, we can treat it as a ValueGetter of T.
late final hasParams = !_constructorText.startsWith('() => ');